==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-et-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Estonian (http://www.transifex.com/tine20/tine20/language/et/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: et\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  ""
 ,""

]
, "Account"
: "Konto"

, "Time Account (Number - Title)"
: ""

, "Billable"
: ""

, "Cleared in"
: ""

, "Invoice"
: ""

, "Cleared"
: ""

, "Date"
: "Kuupäev"

, "Start time"
: ""

, "End time"
: ""

, "Duration"
: ""

, "Description"
: "Kirjeldus"

, "Type"
: ""

, "Time Account closed"
: ""

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Contract"
: ""

, "Title"
: "Pealkiri"

, "Number"
: "Number"

, "Price"
: ""

, "Status"
: "Staatus"

, "Billed"
: ""

, "Cleared at"
: ""

, "Booking deadline"
: "Broneerimise tähtaeg"

, "Responsible"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  ""
 ,""

]
, "Time Account - Status"
: ""

, "closed"
: "suletud"

, "open"
: "avatud"

, "Not a valid time"
: ""

, "Time Account - Billed"
: ""

, "not yet billed"
: ""

, "to bill"
: ""

, "billed"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: ""

, "Select Time Account..."
: ""

, "Start"
: ""

, "not set"
: ""

, "End"
: ""

, "Enter description..."
: ""

, "Need for Clarification"
: ""

, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: ""

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Vaata kõiki"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: ""

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: ""

, "The grant to manage clearing of Timesheets"
: ""

, "without contract"
: ""

, "without responsible"
: ""

, "timeframe"
: ""

, "summary"
: ""

, "Total Timesheets"
: ""

, "Billable Timesheets"
: ""

, "Total Time"
: "Aeg kokku"

, "Time of Billable Timesheets"
: ""

, "Detail"
: "Lisainfo"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: ""

, "Export as CSV"
: ""

, "Export as ..."
: "Ekspordi kui ..."

, "Add New Timeaccount"
: ""

, "Unit"
: "Ühik"

, "Unit Price"
: "Ühiiku hind"

, "Budget"
: "Eelarve"

, "Timesheets are billable"
: ""

, "Access"
: "Ligipääs"

, "Permissions"
: ""

, "Show closed"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "vaikeväärtus"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "pole"

, "last week"
: "viimane nädal"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: ""

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "Timetracker"
: ""

, "Timesheet"
: ""

, "Timeaccount"
: ""

, "Time Account"
: ""

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-et-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Estonian (http://www.transifex.com/tine20/tine20/language/et/)\nLanguage: et\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: ""

, "summary"
: ""

, "Total Timesheets"
: ""

, "Billable Timesheets"
: ""

, "Total Time"
: "Aeg kokku"

, "Time of Billable Timesheets"
: ""

, "Description"
: "Kirjeldus"

, "Detail"
: "Lisainfo"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: ""

, "Export as CSV"
: ""

, "Export as ..."
: "Ekspordi kui ..."

, "Timesheet, Timesheets"
: [
  ""
 ,""

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Ühik"

, "Unit Price"
: "Ühiiku hind"

, "Factor"
: ""

, "Budget"
: "Eelarve"

, "Status"
: "Staatus"

, "closed"
: "suletud"

, "open"
: "avatud"

, "Cleared In"
: ""

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: ""

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  ""
 ,""

]
, "Number"
: "Number"

, "Title"
: "Pealkiri"

, "Access"
: "Ligipääs"

, "Permissions"
: ""

, "Time Account - Billed"
: ""

, "not yet billed"
: ""

, "to bill"
: ""

, "billed"
: ""

, "Time Account - Status"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: ""

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Vaata kõiki"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: ""

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: ""

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: ""

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "vaikeväärtus"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "pole"

, "last week"
: "viimane nädal"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: ""

, "Billed"
: ""

, "Booking deadline"
: "Broneerimise tähtaeg"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Konto"

, "Time Account (Number - Title)"
: ""

, "Billable"
: ""

, "Cleared"
: ""

, "Date"
: "Kuupäev"

, "Start time"
: ""

, "End time"
: ""

, "Duration"
: ""

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: ""

, "Timetracker"
: ""

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Manage timeaccounts"
: ""

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""

, "Timesheet"
: ""

, "Timeaccount"
: ""

, "Time Account"
: ""

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
